@@ -3,10 +3,10 @@
 ;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
-;; Maintainer: notmuch-indicator Development <~protesilaos/notmuch-indicator@lists.sr.ht>
+;; Maintainer: notmuch-indicator Development <~protesilaos/general-issues@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/notmuch-indicator
-;; Mailing-List: https://lists.sr.ht/~protesilaos/notmuch-indicator
-;; Version: 1.0.1
+;; Mailing-List: https://lists.sr.ht/~protesilaos/general-issues
+;; Version: 1.1.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mail
 
@@ -83,8 +83,8 @@
 ;; counters from the indicator, when it is set to a non-nil value.
 ;;
 ;; Finally, and albeit obvious, the backronym for this package is:
-;; notmuch-... Increasingly in Need of Displaying Inconsequential
-;; Counters Alongside Trivia that Obscure Reality.
+;; notmuch-... Interested in Notmuch Data Indicators that Count Any
+;; Terms Ordinarily Requested.
 
 ;;; Code:
 
@@ -159,6 +159,48 @@ option `notmuch-indicator-refresh-count'."
   :type '(repeat function)
   :group 'notmuch-indicator)
 
+(defun notmuch-indicator-get-config-file ()
+  "Return `notmuch' configuration file."
+  (catch 'found
+    (dolist (path '("$XDG_CONFIG_HOME/notmuch/$NOTMUCH_PROFILE/config"
+                    "$HOME/.notmuch-config.$NOTMUCH_PROFILE"
+                    "$HOME/.notmuch-config"))
+      (when-let ((config (substitute-env-vars path))
+                 ((file-exists-p config)))
+        (throw 'found config)))))
+
+(defcustom notmuch-indicator-notmuch-config-file (notmuch-indicator-get-config-file)
+  "File system path to the local user's Notmuch configuration file.
+
+The file is one among:
+
+- $XDG_CONFIG_HOME/notmuch/$NOTMUCH_PROFILE/config
+- $HOME/.notmuch-config.$NOTMUCH_PROFILE
+- $HOME/.notmuch-config
+
+See the function `notmuch-indicator-get-config-file' for how we
+return the right path.  The user can set this user option to an
+arbitrary path if the aforementioned function does not return the
+desired value.
+
+We store this the first time `notmuch-indicator-mode' is loaded
+so that the indicator can still show the data of the local user
+even when they are browsing a remote file system with TRAMP.
+Alternatively, the user may wish to have different indicators
+depending on the TRAMP environment, in which case the value of
+this user option must be updated accordingly (DEV NOTE: please
+contact me if you have such a use-case, as I am happy to make the
+package more flexible)."
+  :type 'file
+  :package-version '(notmuch-indicator . "1.1.0")
+  :group 'notmuch-indicator)
+
+(defcustom notmuch-indicator-notmuch-binary (executable-find "notmuch")
+  "File system path to the `notmuch' binary."
+  :type 'file
+  :package-version '(notmuch-indicator . "1.1.0")
+  :group 'notmuch-indicator)
+
 ;;;; Helper functions and the minor-mode
 
 (defun notmuch-indicator--shell-command (terms)
@@ -166,7 +208,10 @@ option `notmuch-indicator-refresh-count'."
   (replace-regexp-in-string
    "\n" " "
    (shell-command-to-string
-    (format "notmuch count %s" terms))))
+    (format "%s --config=%S count %s"
+            notmuch-indicator-notmuch-binary
+            notmuch-indicator-notmuch-config-file
+            terms))))
 
 (declare-function
  notmuch-search "notmuch"
@@ -187,23 +232,28 @@ option `notmuch-indicator-refresh-count'."
      'help-echo (format "mouse-1: Open notmuch search for `%s'" terms)
      'local-map map)))
 
-(defun notmuch-indicator--format-output (properties)
-  "Format PROPERTIES of `notmuch-indicator-args'."
-  (let ((count (notmuch-indicator--shell-command (plist-get properties :terms))))
-    (if (and (zerop (string-to-number count))
-             notmuch-indicator-hide-empty-counters)
-        ""
-      (notmuch-indicator--format-label
-       (plist-get properties :label)
-       count
-       (plist-get properties :face)
-       (plist-get properties :terms)))))
+(defun notmuch-indicator--format-counter (count properties)
+  "Format counter with COUNT and PROPERTIES of `notmuch-indicator-args'."
+  (notmuch-indicator--format-label
+   (plist-get properties :label)
+   count
+   (plist-get properties :face)
+   (plist-get properties :terms)))
 
-(defun notmuch-indicator--return-count ()
+(defun notmuch-indicator--get-counters ()
+  "Return `notmuch-indicator-args' per `notmuch-indicator-hide-empty-counters'."
+  (delq nil
+        (mapcar
+         (lambda (properties)
+           (let ((count (notmuch-indicator--shell-command (plist-get properties :terms))))
+             (unless (and (zerop (string-to-number count))
+                          notmuch-indicator-hide-empty-counters)
+               (notmuch-indicator--format-counter count properties))))
+         notmuch-indicator-args)))
+
+(defun notmuch-indicator--return-single-string ()
   "Parse `notmuch-indicator-args' and format them as single string."
-  (mapconcat
-   #'notmuch-indicator--format-output
-   notmuch-indicator-args " "))
+  (mapconcat #'identity (notmuch-indicator--get-counters) " "))
 
 (defvar notmuch-indicator-string ""
   "String showing the `notmuch-indicator' state.
@@ -211,9 +261,9 @@ It is appended to the `global-mode-string'.")
 (put 'notmuch-indicator-string 'risky-local-variable t)
 
 (defun notmuch-indicator--indicator ()
-  "Prepare new mail count mode line indicator."
+  "Prepare `notmuch-indicator-string'."
   (setq global-mode-string (delq 'notmuch-indicator-string global-mode-string))
-  (if-let ((count (notmuch-indicator--return-count)))
+  (if-let ((count (notmuch-indicator--return-single-string)))
       (setq notmuch-indicator-string count
             ;; FIXME 2022-09-22: This may be hacky, but I cannot remember or
             ;; find a function that appends an element as the second in a
@@ -229,11 +279,12 @@ It is appended to the `global-mode-string'.")
 
 (defun notmuch-indicator--running-p ()
   "Return non-nil if `notmuch-indicator--indicator' is running."
-  (when (executable-find "notmuch")
+  (when (and notmuch-indicator-notmuch-config-file notmuch-indicator-notmuch-binary)
     (delq nil
-          (mapcar (lambda (timer)
-                    (eq (timer--function timer) 'notmuch-indicator--indicator))
-                  timer-list))))
+          (mapcar
+           (lambda (timer)
+             (eq (timer--function timer) 'notmuch-indicator--indicator))
+           timer-list))))
 
 (defun notmuch-indicator--run ()
   "Run the timer with a delay, starting it if necessary.
